Coverage for aipyapp/__init__.py: 75%

1 from importlib import resources

2

3 from .i18n import T, set_lang, get_lang

4 from .interface import Event, EventBus, EventListener, EventHandler, Stoppable

5 from .plugin import Plugin, PluginError, PluginConfigError, PluginInitError, TaskPlugin, PluginType

6

7 try:

8 from .__version__ import __version__

9 except ImportError:

10 from importlib.metadata import version

11 __version__ = version(__package__)

12

13 __respkg__ = f'{__package__}.res'

14 __respath__ = resources.files(__respkg__)

15 __pkgpath__ = resources.files(__package__)